@@ -318,6 +318,7 @@ int main(int argc, char *argv[])
 	mode=0;
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 	gnome_init_with_popt_table("gmix", VERSION, argc, argv, options,
 				   0, NULL);
@@ -1083,7 +1084,7 @@ void open_dialog(void)
 	
 	int i;
 
-	app = gnome_app_new ("gmix", _("Volume Control") );
+	app = gnome_app_new ("gnome-volume-control", _("Volume Control") );
 	gtk_widget_realize (app);
 	gtk_signal_connect (GTK_OBJECT (app), "delete_event",
 			    GTK_SIGNAL_FUNC (quit_cb),
