@@ -13,7 +13,9 @@
 
 #include <pango/pango.h>
 
+#include "gnome-cd-type.h"
 #include "display.h"
+#include "preferences.h"
 #include "cdrom.h"
 
 #define NUMBER_OF_DISPLAY_LINES 5
@@ -35,7 +37,20 @@ typedef struct _GnomeCDText {
 	GdkColor *background;
 } GnomeCDText;
 
-typedef struct _GnomeCD {
+typedef struct _GCDTheme {
+	char *name;
+	
+	GdkPixbuf *previous, *previous_menu;
+	GdkPixbuf *rewind;
+	GdkPixbuf *play, *play_menu;
+	GdkPixbuf *pause;
+	GdkPixbuf *stop, *stop_menu;
+	GdkPixbuf *forward;
+	GdkPixbuf *next, *next_menu;
+	GdkPixbuf *eject, *eject_menu;
+} GCDTheme;
+
+struct _GnomeCD {
 	GtkWidget *window;
 	GtkWidget *vbox;
 	GtkWidget *display;
@@ -66,7 +81,10 @@ typedef struct _GnomeCD {
 	int height, max_width;
 
 	GnomeCDDiscInfo *disc_info;
-} GnomeCD;
+
+	GCDTheme *theme;
+	GnomeCDPreferences *preferences;
+};
 
 void skip_to_track (GtkWidget *item,
 		    GnomeCD *gcd);
